@@ -168,7 +168,7 @@ class PyMvnGit:
         if not os.path.exists(self._fileDBProject) and not startDatabases:
            print("")
            Console.error("{green}There's no repository created for {iblue}{curdir}{green}, please start it with the command: {iblue}pymvngit start{reset}". \
-                         format(curdir=self._fileDBProject,iblue=Colors.IBLUE,igreen=Colors.IGREEN,green=Colors.GREEN,reset=Color.RESET))
+                         format(curdir=self._fileDBProject,iblue=Colors.IBLUE,igreen=Colors.IGREEN,green=Colors.GREEN,reset=Colors.RESET))
            print("")              
            sys.exit()              
 
